@@ -41,8 +41,6 @@
 
 #define KCODECS_DECL_DEPRECATED_TEXT(text) __attribute__ ((__deprecated__(text)))
 
-#define ECM_GENERATEEXPORTHEADER_VERSION_VALUE(major, minor, patch) ((major<<16)|(minor<<8)|(patch))
-
 /* Take any defaults from group settings */
 #if !defined(KCODECS_NO_DEPRECATED) && !defined(KCODECS_DISABLE_DEPRECATED_BEFORE_AND_AT)
 #  ifdef KF_NO_DEPRECATED
@@ -86,7 +84,7 @@
 #define KCODECS_BUILD_DEPRECATED_SINCE(major, minor) 1
 
 #ifdef KCODECS_NO_DEPRECATED
-#  define KCODECS_DISABLE_DEPRECATED_BEFORE_AND_AT 0x56800
+#  define KCODECS_DISABLE_DEPRECATED_BEFORE_AND_AT 0x56b00
 #endif
 #ifdef KCODECS_NO_DEPRECATED_WARNINGS
 #  define KCODECS_DEPRECATED_WARNINGS_SINCE 0
@@ -96,7 +94,7 @@
 #  ifdef KCODECS_DISABLE_DEPRECATED_BEFORE_AND_AT
 #    define KCODECS_DEPRECATED_WARNINGS_SINCE KCODECS_DISABLE_DEPRECATED_BEFORE_AND_AT
 #  else
-#    define KCODECS_DEPRECATED_WARNINGS_SINCE 0x56800
+#    define KCODECS_DEPRECATED_WARNINGS_SINCE 0x56b00
 #  endif
 #endif
 
@@ -105,7 +103,7 @@
 #endif
 
 #ifdef KCODECS_DEPRECATED
-#  define KCODECS_ENABLE_DEPRECATED_SINCE(major, minor) (ECM_GENERATEEXPORTHEADER_VERSION_VALUE(major, minor, 0) > KCODECS_DISABLE_DEPRECATED_BEFORE_AND_AT)
+#  define KCODECS_ENABLE_DEPRECATED_SINCE(major, minor) (((major<<16)|(minor<<8)) > KCODECS_DISABLE_DEPRECATED_BEFORE_AND_AT)
 #else
 #  define KCODECS_ENABLE_DEPRECATED_SINCE(major, minor) 0
 #endif
